slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSKrylovSchurGetSubcommInfo

Gets information related to the case of doing spectrum slicing for a computational interval with multiple communicators.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSKrylovSchurGetSubcommInfo(EPS eps,PetscInt *k,PetscInt *n,Vec *v)

Collective on the subcommunicator (if v is given)

### Input Parameter

| eps | - the eigenproblem solver context

### Output Parameters

| k | - index of the subinterval for the calling process
| n | - number of eigenvalues found in the k-th subinterval
| v | - a vector owned by processes in the subcommunicator with dimensions compatible for locally computed eigenvectors (or NULL)

### Notes

This function is only available for spectrum slicing runs.

The returned Vec should be destroyed by the user.

### See Also

EPSSetInterval(), EPSKrylovSchurSetPartitions(), EPSKrylovSchurGetSubcommPairs()

### Level

advanced

### Location

src/eps/impls/krylov/krylovschur/krylovschur.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages